.. ref-gs:

==
GS
==

boto.gs.acl
-----------

.. automodule:: boto.gs.acl
   :members:
   :inherited-members:
   :undoc-members:

boto.gs.bucket
--------------

.. automodule:: boto.gs.bucket
   :members:
   :inherited-members:
   :undoc-members:
   :exclude-members: BucketPaymentBody, LoggingGroup, MFADeleteRE, VersionRE,
                     VersioningBody, WebsiteBody, WebsiteErrorFragment,
                     WebsiteMainPageFragment, startElement, endElement

boto.gs.bucketlistresultset
---------------------------

.. automodule:: boto.gs.bucketlistresultset
   :members:
   :inherited-members:
   :undoc-members:

boto.gs.connection
------------------

.. automodule:: boto.gs.connection
   :members:
   :inherited-members:
   :undoc-members:

boto.gs.cors
------------

.. automodule:: boto.gs.cors
   :members:
   :undoc-members:

boto.gs.key
-----------

.. automodule:: boto.gs.key
   :members:
   :inherited-members:
   :undoc-members:

boto.gs.user
------------

.. automodule:: boto.gs.user
   :members:
   :inherited-members:
   :undoc-members:

boto.gs.resumable_upload_handler
--------------------------------

.. automodule:: boto.gs.resumable_upload_handler
   :members:
   :inherited-members:
   :undoc-members:

